"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Frame = void 0;
const react_1 = __importStar(require("react"));
const classnames_1 = __importDefault(require("classnames"));
const react_dom_1 = require("@floating-ui/react-dom");
const frame_module_scss_1 = __importDefault(require("./frame.module.scss"));
/** frame padding around the target */
const MARGIN_FROM_TARGET = +frame_module_scss_1.default.offset || 6; // setting fallback 6, for tests
/** min. distance from the edge of the screen. */
const MARGIN_FROM_DOC_EDGE = 0;
// position - bottom start (bottom left corner)
// x - width - horizontal (cross axis)
// y - height - vertical (main axis)
function Frame({ targetRef, watchMotion, className, stylesClass = frame_module_scss_1.default.overlayBorder, style }) {
    const dimensionRef = (0, react_1.useRef)({ width: 0, height: 0 });
    const shiftRef = (0, react_1.useRef)();
    const { x, y, strategy, reference, floating, update, refs } = (0, react_dom_1.useFloating)({
        placement: 'bottom-start',
        middleware: [
            // replace dimensions from previous iterations with the target's size
            // this is only the measured size, not yet the applied size
            {
                name: 'align-to-target',
                fn({ rects }) {
                    rects.floating = Object.assign(Object.assign({}, rects.floating), { width: rects.reference.width + 2 * MARGIN_FROM_TARGET, height: rects.reference.height + 2 * MARGIN_FROM_TARGET });
                    return {};
                },
            },
            // reposition x,y, to the top of the reference
            (0, react_dom_1.offset)((options) => -options.reference.height),
            // offset the frame by its extra padding
            (0, react_dom_1.offset)(() => ({ mainAxis: -MARGIN_FROM_TARGET, crossAxis: -MARGIN_FROM_TARGET })),
            // push the frame inside the screen
            (0, react_dom_1.shift)({ rootBoundary: 'document', padding: MARGIN_FROM_DOC_EDGE, mainAxis: true, crossAxis: true }),
            // read "shift" for the size-apply() method (because it doesn't forward middlewareData)
            {
                name: 'read-shift',
                fn({ middlewareData }) {
                    shiftRef.current = middlewareData.shift;
                    return {};
                },
            },
            // size also applies overflow detection via width and height
            (0, react_dom_1.size)({
                // apply overflow detection in reference to the document
                rootBoundary: 'document',
                padding: MARGIN_FROM_DOC_EDGE,
                apply({ reference: referenceRect, height, width }) {
                    var _a, _b, _c;
                    const paddingX = 2 * MARGIN_FROM_TARGET - (((_a = shiftRef.current) === null || _a === void 0 ? void 0 : _a.x) || 0);
                    const paddingY = 2 * MARGIN_FROM_TARGET - (((_b = shiftRef.current) === null || _b === void 0 ? void 0 : _b.y) || 0);
                    dimensionRef.current = {
                        width: Math.min(referenceRect.width + paddingX, width),
                        height: Math.min(referenceRect.height + paddingY, height),
                    };
                    Object.assign((_c = refs.floating.current) === null || _c === void 0 ? void 0 : _c.style, dimensionRef.current);
                },
            }),
        ],
    });
    // set target as floating reference
    (0, react_1.useLayoutEffect)(() => {
        reference(targetRef.current);
    }, [targetRef.current]);
    // automatically update on scroll, resize, etc.
    // `watchMotion` will trigger continuous updates using animation frame
    (0, react_1.useEffect)(() => {
        if (!refs.reference.current || !refs.floating.current)
            return () => { };
        return (0, react_dom_1.autoUpdate)(refs.reference.current, refs.floating.current, update, { animationFrame: watchMotion });
    }, [refs.reference.current, refs.floating.current, update, watchMotion]);
    const isReady = x !== null;
    return (react_1.default.createElement("div", { ref: floating, className: (0, classnames_1.default)(className, stylesClass, !isReady && frame_module_scss_1.default.hidden), style: Object.assign(Object.assign(Object.assign({}, style), dimensionRef.current), { position: strategy, 
            // starting at pos [0,0] will ensure the label doesn't increase the document size.
            top: y !== null && y !== void 0 ? y : 0, left: x !== null && x !== void 0 ? x : 0 }) }));
}
exports.Frame = Frame;
//# sourceMappingURL=frame.js.map